@@ -26,7 +26,7 @@ def activate_venv(path):
 
     # set current directory
     os.chdir(path)
-    print("🔨🔨 setting up your virutal environment")
+    print("🔨 setting up your virutal environment")
     os.system("python -m venv venv")
     os.getcwd()
 
@@ -35,7 +35,7 @@ def activate_venv(path):
         env_activate_script = "Scripts"
 
     activate_file = os.path.join(path, "venv", env_activate_script, "activate")
-    print("🔧🔧 downloading packages")
+    print("🔨 downloading packages")
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
 
@@ -50,5 +50,10 @@ def start(template_name):
     
     if OS == "Windows":
         activate_file = os.path.join("venv", "Scripts", "activate")
-        print(f"cd {folder_name.name}; {activate_file}")
+        
 
+    print("To start the project run the following commands:")
+    print(f"cd {folder_name.name}; {activate_file}")
+    print("python manage.py makemigations")
+    print("python manage.py migrate")
+    print("python manage.py runserver")
\ No newline at end of file
